==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/EC2/AssociateTransitGatewayRouteTable.pm <==

package Paws::EC2::AssociateTransitGatewayRouteTable;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has TransitGatewayAttachmentId => (is => 'ro', isa => 'Str', required => 1);
  has TransitGatewayRouteTableId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AssociateTransitGatewayRouteTable');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::AssociateTransitGatewayRouteTableResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::AssociateTransitGatewayRouteTable - Arguments for method AssociateTransitGatewayRouteTable on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method AssociateTransitGatewayRouteTable on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method AssociateTransitGatewayRouteTable.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AssociateTransitGatewayRouteTable.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $AssociateTransitGatewayRouteTableResult =
      $ec2->AssociateTransitGatewayRouteTable(
      TransitGatewayAttachmentId => 'MyString',
      TransitGatewayRouteTableId => 'MyString',
      DryRun                     => 1,            # OPTIONAL
      );

    # Results:
    my $Association = $AssociateTransitGatewayRouteTableResult->Association;

    # Returns a L<Paws::EC2::AssociateTransitGatewayRouteTableResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/AssociateTransitGatewayRouteTable>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> TransitGatewayAttachmentId => Str

The ID of the attachment.



=head2 B<REQUIRED> TransitGatewayRouteTableId => Str

The ID of the transit gateway route table.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AssociateTransitGatewayRouteTable in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/EC2/AssociateTransitGatewayRouteTable.pm <==

package Paws::EC2::AssociateTransitGatewayRouteTable;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has TransitGatewayAttachmentId => (is => 'ro', isa => 'Str', required => 1);
  has TransitGatewayRouteTableId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AssociateTransitGatewayRouteTable');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::AssociateTransitGatewayRouteTableResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::AssociateTransitGatewayRouteTable - Arguments for method AssociateTransitGatewayRouteTable on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method AssociateTransitGatewayRouteTable on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method AssociateTransitGatewayRouteTable.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AssociateTransitGatewayRouteTable.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $AssociateTransitGatewayRouteTableResult =
      $ec2->AssociateTransitGatewayRouteTable(
      TransitGatewayAttachmentId => 'MyTransitGatewayAttachmentId',
      TransitGatewayRouteTableId => 'MyTransitGatewayRouteTableId',
      DryRun                     => 1,                                # OPTIONAL
      );

    # Results:
    my $Association = $AssociateTransitGatewayRouteTableResult->Association;

    # Returns a L<Paws::EC2::AssociateTransitGatewayRouteTableResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/AssociateTransitGatewayRouteTable>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> TransitGatewayAttachmentId => Str

The ID of the attachment.



=head2 B<REQUIRED> TransitGatewayRouteTableId => Str

The ID of the transit gateway route table.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AssociateTransitGatewayRouteTable in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
